#!/usr/bin/env python

# Currently only tested with Python3
from __future__ import print_function

# For more info on the Core V3 API, see:
#   https://api.core.ac.uk/docs/v3
#
# The default DOI value used below is based on the one given in the Core V3 API documentation


import os
import sys
import json

import argparse

import requests
import urllib.parse

import util


apiKey = util.readKey("oacore-key.txt")


base_url = "https://api.core.ac.uk/v3"

search_work_url = base_url+"/search/works/"
discover_url    = base_url+"/discover"

headers = {
    'Content-type': 'application/json'
}


def getDOI(doi):
    
    query_args = "api_key="+apiKey+"&q="+urllib.parse.quote_plus("doi:\""+doi+"\"")
    query_url  = search_work_url + "?" + query_args

    # print("query_url="+query_url)

    # Based on:
    #    https://stackoverflow.com/questions/25491090/how-to-use-python-to-execute-a-curl-command
    
    response = requests.get(query_url, headers=headers)

    
    #data = '{}'
    # More work to be done to see if the following can be made to work
    #data = {
    #    "api_key": apiKey,
    #    "q":       "doi:\""+doi+"\""
    #}
    #response = requests.get(query_url, headers=headers, data=data)


    returned_json_str = response.content
    
    returned_json = json.loads(returned_json_str)

    return returned_json


        
if __name__ == "__main__":

    parser = argparse.ArgumentParser()
    #parser.add_argument('--sheetname', help="The name of the sheet within the Excel file to extractc data from")
    #parser.add_argument('--votingtype', choices=["J","T", "JT"], help="Filter to only J=Jury, T=Tele cast votes, JT=Combined jury and tele votes")
    parser.add_argument('doi', nargs='?')
    parser.add_argument('output-file.json', nargs='?')
    
    args = parser.parse_args()

    #sheetname = getattr(args,'sheetname');
    #voting_type = getattr(args,'votingtype');
    
    doi = getattr(args,'doi');
    if (doi == None):        
        oacore_example_doi="10.1016/0370-2693(96)00910-0"
    
        # Bainbridge et al example, IJDL user-centric approach ...
        stinky_doi="10.1145/1998076.1998084"
    
        print("As a default, selecting Core example DOI: " + oacore_example_doi)
        doi = oacore_example_doi

    json_output_filename = getattr(args,'output-file.json');
    if (json_output_filename == None):
        encoded_doi = urllib.parse.quote_plus(doi)        
        json_output_filename = "oacore-"+encoded_doi+".json"
    
    returned_json = getDOI(doi)
    returned_json_prettyprint = json.dumps(returned_json, indent=2, ensure_ascii=False)

    print("Saving returned JSON output to: " + json_output_filename)

    with open(json_output_filename, 'w', encoding="utf8") as fout:
        fout.write(returned_json_prettyprint)

    
# Or consider using their Python API:
#
#    https://github.com/oacore/pyoacore

# They also support Java, R and (it looks like) NodeJS


# https://core.ac.uk/search?q=doi%3A%2210.1186%2F1471-2458-6-309%22&page=1
